@@ -108,8 +108,8 @@ Classifiers_Use_Server <- function(id, log_dir, volumes) {
         # Try to load the model
         model <- try(load_from_disk(model_path), silent = TRUE)
 
-        if ("try-error" %in% class(model) == FALSE) {
-          if ("ClassifiersBasedOnTextEmbeddings" %in% class(model)) {
+        if (inherits(model, "try-error") == FALSE) {
+          if (inherits(model, "ClassifiersBasedOnTextEmbeddings")) {
             shiny::removeModal()
             return(model)
           } else {
