@@ -76,12 +76,12 @@ check_errors_create_classifier <- function(classifier_type,
     ))
   } else {
     embeddings <- try(load_from_disk(path_to_embeddings), silent = TRUE)
-    if ("try-error" %in% class(embeddings)) {
+    if (inherits(embeddings, "try-error")) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         embeddings
       ))
     } else if (
-      !("LargeDataSetForTextEmbeddings" %in% class(embeddings) || "EmbeddedText" %in% class(embeddings))
+      !(inherits(embeddings, "LargeDataSetForTextEmbeddings") || inherits(embeddings, "EmbeddedText"))
     ) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         "Directory which should store embeddings does not contain an object of class 'LargeDataSetForTextEmbeddings'
@@ -100,11 +100,11 @@ check_errors_create_classifier <- function(classifier_type,
       ))
     } else {
       feature_extractor <- try(load_from_disk(path_to_feature_extractor), silent = TRUE)
-      if ("try-error" %in% class(feature_extractor)) {
+      if (inherits(feature_extractor, "try-error")) {
         error_list[length(error_list) + 1] <- list(shiny::tags$p(
           feature_extractor
         ))
-      } else if (!("TEFeatureExtractor" %in% class(feature_extractor))) {
+      } else if (!(inherits(feature_extractor, "TEFeatureExtractor"))) {
         error_list[length(error_list) + 1] <- list(shiny::tags$p(
           "Directory which should contain a feature extractor does not contain an object of class
           TEFeatureExtractor."
@@ -147,7 +147,7 @@ check_errors_create_classifier <- function(classifier_type,
 
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -232,7 +232,7 @@ check_errors_create_dataset_raw_texts <- function(source_path,
 
   tmp_ui_error <- NULL
   if (length(error_list) > 0) {
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -291,12 +291,12 @@ check_errors_create_feature_extractor <- function(destination_path,
     ))
   } else {
     embeddings <- try(load_from_disk(path_to_embeddings), silent = TRUE)
-    if ("try-error" %in% class(embeddings)) {
+    if (inherits(embeddings, "try-error")) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         embeddings
       ))
     } else if (
-      !("LargeDataSetForTextEmbeddings" %in% class(embeddings) || "EmbeddedText" %in% class(embeddings))
+      !(inherits(embeddings, "LargeDataSetForTextEmbeddings") || inherits(embeddings, "EmbeddedText"))
     ) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         "Directory which should store embeddings does not contain an object of class 'LargeDataSetForTextEmbeddings'
@@ -323,7 +323,7 @@ check_errors_create_feature_extractor <- function(destination_path,
 
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -357,7 +357,7 @@ check_errors_predict_classifier <- function(embeddings,
 
   # Embeddings
   if (
-    !("LargeDataSetForTextEmbeddings" %in% class(embeddings) || "EmbeddedText" %in% class(embeddings))
+    !(inherits(embeddings, "LargeDataSetForTextEmbeddings") || inherits(embeddings, "EmbeddedText"))
   ) {
     error_list[length(error_list) + 1] <- list(shiny::tags$p(
       "Directory which should store embeddings does not contain an object of class 'LargeDataSetForTextEmbeddings'
@@ -377,7 +377,7 @@ check_errors_predict_classifier <- function(embeddings,
 
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -425,10 +425,10 @@ check_errors_text_embedding_model_embed <- function(destination_path,
     error_list[length(error_list) + 1] <- list(shiny::tags$p("There is no file at the current path."))
   } else {
     raw_texts <- try(load_from_disk(dir_path = path_to_raw_texts), silent = TRUE)
-    if ("try-error" %in% class(raw_texts)) {
+    if (inherits(raw_texts, "try-error")) {
       error_list[length(error_list) + 1] <- raw_texts
     } else {
-      if (!"LargeDataSetForText" %in% class(raw_texts)) {
+      if (!inherits(raw_texts, "LargeDataSetForText")) {
         error_list[length(error_list) + 1] <- paste("The object is not of class LargeDataSetForText")
       }
     }
@@ -438,7 +438,7 @@ check_errors_text_embedding_model_embed <- function(destination_path,
   # summary
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -494,7 +494,7 @@ check_errors_text_embedding_model_create <- function(destination_path,
 
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -533,12 +533,12 @@ check_error_base_model_create_or_train <- function(destination_path,
     ))
   } else {
     raw_texts <- try(load_from_disk(path_to_raw_texts), silent = TRUE)
-    if ("try-error" %in% class(raw_texts)) {
+    if (inherits(raw_texts, "try-error")) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         raw_texts
       ))
     } else if (
-      !("LargeDataSetForText" %in% class(raw_texts))
+      !(inherits(raw_texts, "LargeDataSetForText"))
     ) {
       error_list[length(error_list) + 1] <- list(shiny::tags$p(
         "Directory which should store the raw texts does not contain an object of class 'LargeDataSetForText'."
@@ -548,7 +548,7 @@ check_error_base_model_create_or_train <- function(destination_path,
 
   if (length(error_list) > 0) {
     tmp_ui_error <- NULL
-    for (i in seq_len(length(error_list))) {
+    for (i in seq_along(error_list)) {
       tmp_ui_error[length(tmp_ui_error) + 1] <- list(
         shiny::tags$p(error_list[i])
       )
@@ -559,7 +559,17 @@ check_error_base_model_create_or_train <- function(destination_path,
   }
 }
 
-load_and_check_base_model=function(path){
-  model=transformers$AutoModel$from_pretrained(path)
+load_and_check_base_model <- function(path) {
+  if (file.exists(paste0(path, "/", "r_config_state.rda"))) {
+    model <- load_from_disk(path)
+  } else {
+    tmp_pytorch_model <- transformers$AutoModelForMaskedLM$from_pretrained(model_dir = path)
+    tmp_type <- detect_base_model_type(tmp_pytorch_model)
+    model <- create_object(tmp_type)
+    model$create_from_hf(
+      model_dir = path,
+      tokenizer_dir = path
+    )
+  }
   return(model)
 }
