@@ -19,9 +19,9 @@
 #' All models of this class require text embeddings as input. These are provided as
 #' objects of class [EmbeddedText] or [LargeDataSetForTextEmbeddings].
 #'
-#'Objects of this class containing fields and methods used in several other classes in 'AI for Education'.
+#' Objects of this class containing fields and methods used in several other classes in 'AI for Education'.
 #'
-#'This class is **not** designed for a direct application and should only be used by developers.
+#' This class is **not** designed for a direct application and should only be used by developers.
 #'
 #' @return A new object of this class.
 #' @family R6 Classes for Developers
@@ -54,7 +54,7 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
 
       # Check original text embedding model
       embedding_model_config <- text_embeddings$get_model_info()
-      check <- c("model_name")
+      check <- "model_name"
 
       if (
         !is.null_or_na(embedding_model_config[[check]]) &
@@ -66,6 +66,19 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         }
       }
     },
+    #-------------------------------------------------------------------------
+    #' @description Method for saving a model.
+    #' @param dir_path `string` Path of the directory where the model should be saved.
+    #' @param folder_name `string` Name of the folder that should be created within the directory.
+    #' @return Function does not return a value. It saves the model to disk.
+    #' @importFrom utils write.csv
+    save = function(dir_path, folder_name) {
+      # Save pytorch model
+      private$save_pytorch_model(dir_path = dir_path, folder_name = folder_name)
+
+      # Saving Sustainability Data
+      private$save_sustainability_data(dir_path = dir_path, folder_name = folder_name)
+    },
     #--------------------------------------------------------------------------
     #' @description loads an object from disk and updates the object to the current version of the package.
     #' @param dir_path Path where the object set is stored.
@@ -85,22 +98,26 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
 
       # Call the core method which loads data common for all models.
       # These are documentations, licenses, model's name and label etc.
-      private$load_base_config_and_docs_general(
-        config_public = config_file$public,
-        config_private = config_file$private
-      )
+      private$load_config_file(dir_path)
+
+      # private$load_base_config_and_docs_general(
+      #  config_public = config_file$public,
+      #  config_private = config_file$private
+      # )
 
       # Check and update model_config
       # Call this method to add parameters that where added in later version
       # which are missing in the old model
-      private$update_model_config()
+      # private$update_model_config()
 
-      #Check and update pad value if necessary
+      # Check and update pad value if necessary
       private$update_pad_value()
 
       # Create and load AI model
-      private$create_reset_model()
-      self$load(dir_path = dir_path)
+      private$load_pytorch_model(dir_path = dir_path)
+
+      # Load sustainability data
+      private$load_sustainability_data(model_dir = dir_path)
 
       # Set training status
       private$trained <- config_file$private$trained
@@ -119,12 +136,12 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
     #' @param y_max Maximal value for the y-axis. Set to `NULL` for an automatic adjustment.
     #' @param text_size Size of the text.
     #' @return Returns a plot of class `ggplot` visualizing the training process.
-    plot_training_history=function(final_training=FALSE,pl_step=NULL,measure="loss",y_min=NULL,y_max=NULL,add_min_max=TRUE,text_size=10){
-        requireNamespace("ggplot2")
-        plot_data <- private$prepare_training_history(
-          final = final_training,
-          pl_step = pl_step
-        )
+    plot_training_history = function(final_training = FALSE, pl_step = NULL, measure = "loss", y_min = NULL, y_max = NULL, add_min_max = TRUE, text_size = 10L) {
+      requireNamespace("ggplot2")
+      plot_data <- private$prepare_training_history(
+        final = final_training,
+        pl_step = pl_step
+      )
 
       # Select the performance measure to display
       plot_data <- plot_data[[measure]]
@@ -140,12 +157,12 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         y_label <- "Average Iota"
       }
 
-      plot <- ggplot2::ggplot(data = plot_data) +
+      tmp_plot <- ggplot2::ggplot(data = plot_data) +
         ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$train_mean, color = "train")) +
         ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$validation_mean, color = "validation"))
 
-      if (add_min_max == TRUE) {
-        plot <- plot +
+      if (add_min_max) {
+        tmp_plot <- tmp_plot +
           ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$train_min, color = "train")) +
           ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$train_max, color = "train")) +
           ggplot2::geom_ribbon(
@@ -171,10 +188,10 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
       }
 
       if ("test_mean" %in% colnames(plot_data)) {
-        plot <- plot +
+        tmp_plot <- tmp_plot +
           ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$test_mean, color = "test"))
-        if (add_min_max == TRUE) {
-          plot <- plot +
+        if (add_min_max) {
+          tmp_plot <- tmp_plot +
             ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$test_min, color = "test")) +
 
             ggplot2::geom_line(ggplot2::aes(x = .data$epoch, y = .data$test_max, color = "test")) +
@@ -190,20 +207,20 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         }
       }
 
-      plot <- plot + ggplot2::theme_classic() +
+      tmp_plot <- tmp_plot + ggplot2::theme_classic() +
         ggplot2::ylab(y_label) +
         ggplot2::coord_cartesian(ylim = c(y_min, y_max)) +
         ggplot2::xlab("epoch") +
         ggplot2::scale_color_manual(values = c(
-          "train" = "red",
-          "validation" = "blue",
-          "test" = "darkgreen"
+          train = "red",
+          validation = "blue",
+          test = "darkgreen"
         )) +
         ggplot2::theme(
           text = ggplot2::element_text(size = text_size),
           legend.position = "bottom"
         )
-      return(plot)
+      return(tmp_plot)
     }
   ),
   private = list(
@@ -214,10 +231,10 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
     ),
     #------------------------------------------------------------------------------
     load_config_and_docs_textembeddingmodel = function(config_public, config_private) {
-      if(is.null(config_private$text_embedding_model$pad_value)){
-        pad_value=0
+      if (is.null(config_private$text_embedding_model$pad_value)) {
+        pad_value <- 0L
       } else {
-        pad_value=config_private$text_embedding_model$pad_value
+        pad_value <- config_private$text_embedding_model$pad_value
       }
 
       private$set_text_embedding_model(
@@ -225,24 +242,24 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         feature_extractor_info = config_private$text_embedding_model$feature_extractor,
         times = config_private$text_embedding_model$times,
         features = config_private$text_embedding_model$features,
-        pad_value=pad_value
+        pad_value = pad_value
       )
     },
     #---------------------------------------------------------------------------
     check_embeddings_object_type = function(embeddings, strict = TRUE) {
-      if (strict == TRUE) {
+      if (strict) {
         if (
-          !("EmbeddedText" %in% class(embeddings)) &
-            !("LargeDataSetForTextEmbeddings" %in% class(embeddings))
+          !(inherits(embeddings, "EmbeddedText")) &
+            !(inherits(embeddings, "LargeDataSetForTextEmbeddings"))
         ) {
           stop("text_embeddings must be of class EmbeddedText or LargeDataSetForTextEmbeddings.")
         }
       } else {
         if (
-          !("EmbeddedText" %in% class(embeddings)) &
-            !("LargeDataSetForTextEmbeddings" %in% class(embeddings)) &
-            !("array" %in% class(embeddings)) &
-            !("datasets.arrow_dataset.Dataset" %in% class(embeddings))
+          !(inherits(embeddings, "EmbeddedText")) &
+            !(inherits(embeddings, "LargeDataSetForTextEmbeddings")) &
+            !(inherits(embeddings, "array")) &
+            !(inherits(embeddings, "datasets.arrow_dataset.Dataset"))
         ) {
           stop("text_embeddings must be of class EmbeddedText, LargeDataSetForTextEmbeddings,
                datasets.arrow_dataset.Dataset or array.")
@@ -252,30 +269,30 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
     #-------------------------------------------------------------------------
     check_single_prediction = function(embeddings) {
       if (
-        "EmbeddedText" %in% class(embeddings) |
-          "LargeDataSetForTextEmbeddings" %in% class(embeddings)
+        inherits(embeddings, "EmbeddedText") |
+          inherits(embeddings, "LargeDataSetForTextEmbeddings")
       ) {
-        if (embeddings$n_rows() > 1) {
+        if (embeddings$n_rows() > 1L) {
           single_prediction <- FALSE
         } else {
           single_prediction <- TRUE
         }
-      } else if ("array" %in% class(embeddings)) {
-        if (nrow(embeddings) > 1) {
+      } else if (inherits(embeddings, "array")) {
+        if (nrow(embeddings) > 1L) {
           single_prediction <- FALSE
         } else {
           single_prediction <- TRUE
         }
-      } else if ("datasets.arrow_dataset.Dataset" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "datasets.arrow_dataset.Dataset")) {
         single_prediction <- FALSE
       }
       return(single_prediction)
     },
     #--------------------------------------------------------------------------
     prepare_embeddings_as_dataset = function(embeddings) {
-      if ("datasets.arrow_dataset.Dataset" %in% class(embeddings)) {
+      if (inherits(embeddings, "datasets.arrow_dataset.Dataset")) {
         prepared_dataset <- embeddings
-      } else if ("EmbeddedText" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "EmbeddedText")) {
         prepared_dataset <- datasets$Dataset$from_dict(
           reticulate::dict(
             list(
@@ -291,7 +308,7 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
             convert = FALSE
           )
         )
-      } else if ("array" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "array")) {
         prepared_dataset <- datasets$Dataset$from_dict(
           reticulate::dict(
             list(
@@ -301,42 +318,42 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
             convert = FALSE
           )
         )
-      } else if ("LargeDataSetForTextEmbeddings" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "LargeDataSetForTextEmbeddings")) {
         prepared_dataset <- embeddings$get_dataset()
       }
       return(prepared_dataset)
     },
     #-------------------------------------------------------------------------
     prepare_embeddings_as_np_array = function(embeddings) {
-      if ("EmbeddedText" %in% class(embeddings)) {
+      if (inherits(embeddings, "EmbeddedText")) {
         prepared_dataset <- embeddings$embeddings
         tmp_np_array <- np$array(prepared_dataset)
-      } else if ("array" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "array")) {
         prepared_dataset <- embeddings
         tmp_np_array <- np$array(prepared_dataset)
-      } else if ("datasets.arrow_dataset.Dataset" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "datasets.arrow_dataset.Dataset")) {
         prepared_dataset <- embeddings$set_format("np")
         tmp_np_array <- prepared_dataset["input"]
-      } else if ("LargeDataSetForTextEmbeddings" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "LargeDataSetForTextEmbeddings")) {
         prepared_dataset <- embeddings$get_dataset()
         prepared_dataset$set_format("np")
         tmp_np_array <- prepared_dataset["input"]
       }
       tmp_np_array <- reticulate::np_array(tmp_np_array)
-      if (numpy_writeable(tmp_np_array) == FALSE) {
+      if (!numpy_writeable(tmp_np_array)) {
         warning("Numpy array is not writable")
       }
       return(tmp_np_array)
     },
     #--------------------------------------------------------------------------
     get_rownames_from_embeddings = function(embeddings) {
-      if ("EmbeddedText" %in% class(embeddings)) {
+      if (inherits(embeddings, "EmbeddedText")) {
         return(rownames(embeddings$embeddings))
-      } else if ("array" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "array")) {
         return(rownames(embeddings))
-      } else if ("datasets.arrow_dataset.Dataset" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "datasets.arrow_dataset.Dataset")) {
         return(embeddings["id"])
-      } else if ("LargeDataSetForTextEmbeddings" %in% class(embeddings)) {
+      } else if (inherits(embeddings, "LargeDataSetForTextEmbeddings")) {
         embeddings$get_ids()
       }
     },
@@ -352,58 +369,34 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
       private$text_embedding_model["features"] <- features
       private$text_embedding_model["pad_value"] <- pad_value
     },
-    save_all_args = function(args, group = "training") {
-      if (group %in% c("configure", "training")) {
-        if (group == "training") {
-          for (arg in names(args)) {
-            if (!R6::is.R6(args[[arg]]) &
-              !is.factor(args[[arg]]) &
-              !arg %in% c("log_dir", "log_write_interval")) {
-              self$last_training$config[arg] <- list(args[[arg]])
-            }
-          }
-        } else if (group == "configure") {
-          for (arg in names(args)) {
-            if (!R6::is.R6(args[[arg]]) &
-              !is.factor(args[[arg]]) &
-              !arg %in% c("log_dir", "log_write_interval")) {
-              self$model_config[arg] <- list(args[[arg]])
-            }
-          }
-        }
-      } else {
-        stop("Argument 'group' must be 'configure' or 'training'.")
-      }
-    },
     set_up_logger = function(log_dir, log_write_interval) {
       private$log_config$log_dir <- log_dir
-      private$log_config$log_state_file <- paste0(private$log_config$log_dir, "/aifeducation_state.log")
+      private$log_config$log_state_file <- file.path(private$log_config$log_dir, "aifeducation_state.log")
       private$log_config$log_write_interval <- log_write_interval
     },
     #-------------------------------------------------------------------------
     # This Method updates the model config in the case that new parameters have been
     # introduced
     update_model_config = function() {
-
-      #Check if an update is necessary
+      # Check if an update is necessary
       current_pkg_version <- self$get_package_versions()$r_package_versions$aifeducation
       if (is.null_or_na(current_pkg_version)) {
-        update <- TRUE
+        need_update <- TRUE
       } else {
         if (check_versions(
           a = packageVersion("aifeducation"),
           operator = ">",
           b = self$get_package_versions()$r_package_versions$aifeducation
         )) {
-          update <- TRUE
+          need_update <- TRUE
         } else {
-          update <- FALSE
+          need_update <- FALSE
         }
       }
 
-      #check if an update of values is necessary. This is the case if the model
-      #was created with an older version of aifeducation compared to 1.1.0
-      #Update values to the new values introduced in version 1.1.0
+      # check if an update of values is necessary. This is the case if the model
+      # was created with an older version of aifeducation compared to 1.1.0
+      # Update values to the new values introduced in version 1.1.0
       if (is.null_or_na(current_pkg_version)) {
         update_values <- TRUE
       } else {
@@ -418,22 +411,22 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         }
       }
 
-      if (update) {
+      if (need_update) {
         param_dict <- get_param_dict()
         if (is.function(self$configure)) {
           param_names_new <- rlang::fn_fmls_names(self$configure)
           for (param in param_names_new) {
             if (is_valid_and_exportable_param(arg_name = param, param_dict = param_dict)) {
-              if (is.null(self$model_config[[param]])) {
+              if (is.null(private$model_config[[param]])) {
                 if (!is.null(param_dict[[param]]$default_historic)) {
-                  self$model_config[param] <- list(param_dict[[param]]$default_historic)
+                  private$model_config[param] <- list(param_dict[[param]]$default_historic)
                 } else {
-                  warning(paste("Historic default for", param, "is missing in parameter dictionary."))
+                  warning("Historic default for ", param, " is missing in parameter dictionary.")
                 }
               }
             }
-            if(update_values){
-              self$model_config[param]=list(update_values_to_new_1.1.0(self$model_config[[param]]))
+            if (update_values) {
+              private$model_config[param] <- list(update_values_to_new_1.1.0(private$model_config[[param]]))
             }
           }
 
@@ -443,37 +436,34 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
           warning("Class does not have a method `configure`.")
         }
       }
-      #print(self$model_config)
-
-
     },
     #-------------------------------------------------------------------------
-    update_pad_value=function(){
+    update_pad_value = function() {
       current_pkg_version <- self$get_package_versions()$r_package_versions$aifeducation
       if (is.na(current_pkg_version)) {
-        update <- TRUE
+        need_update <- TRUE
       } else {
         if (check_versions(
           a = packageVersion("aifeducation"),
           operator = ">",
           b = self$get_package_versions()$r_package_versions$aifeducation
         )) {
-          update <- TRUE
+          need_update <- TRUE
         } else {
-          update <- FALSE
+          need_update <- FALSE
         }
       }
 
-      if (update) {
-        if(is.null_or_na(private$text_embedding_model["pad_value"])){
-          private$text_embedding_model["pad_value"] <- 0
+      if (need_update) {
+        if (is.null_or_na(private$text_embedding_model[["pad_value"]])) {
+          private$text_embedding_model["pad_value"] <- 0L
         }
       }
     },
     #--------------------------------------------------------------------------
     generate_model_id = function(name) {
       if (is.null(name)) {
-        return(paste0("mbote_",generate_id(16)))
+        return(paste0("mbote_", generate_id(16L)))
       } else {
         return(name)
       }
@@ -489,27 +479,29 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
     #'
     #'  Utils Studio Developers
     #'  internal
-    prepare_training_history=function(final = FALSE,
-                                      pl_step = NULL) {
+    prepare_training_history = function(final = FALSE,
+                                        pl_step = NULL) {
       plot_data <- self$last_training$history
 
-      if(length(plot_data)<=1){
-        plot_data[[1]] <- list(loss = plot_data[[1]])
+      if (length(plot_data) <= 1L) {
+        plot_data[[1L]] <- list(loss = plot_data[[1L]])
       }
 
-      #if ("TEFeatureExtractor" %in% class(model)) {
+      # if ("TEFeatureExtractor" %in% class(model)) {
       #  plot_data[[1]] <- list(loss = plot_data[[1]])
-      #}
+      # }
 
-      if (is.null_or_na(final)) final <- FALSE
-
-      if(is.null_or_na(self$last_training$config$use_pl)){
-        use_pl=FALSE
-      } else {
-        use_pl=self$last_training$config$use_pl
+      if (is.null_or_na(final)) {
+        final <- FALSE
       }
 
-      if(use_pl==TRUE & is.null_or_na(pl_step)){
+      if (is.null_or_na(self$last_training$config$use_pl)) {
+        use_pl <- FALSE
+      } else {
+        use_pl <- self$last_training$config$use_pl
+      }
+
+      if (use_pl & is.null_or_na(pl_step)) {
         stop("Model was trained with pseudo labeling. Please provide a pl_step.")
       }
 
@@ -519,31 +511,31 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
 
       # Get information about the existence of a training, validation, and test data set
       # Get Number of folds for the request
-      if (final == FALSE) {
+      if (!final) {
         n_folds <- length(self$last_training$history)
-        if (n_folds > 1) {
-          n_folds <- n_folds - 1
+        if (n_folds > 1L) {
+          n_folds <- n_folds - 1L
         }
 
         if (!use_pl) {
-          measures <- names(plot_data[[1]])
-          n_sample_type <- nrow(plot_data[[1]][[measures[1]]])
+          measures <- names(plot_data[[1L]])
+          n_sample_type <- nrow(plot_data[[1L]][[measures[1L]]])
         } else {
-          measures <- names(plot_data[[1]][[1]])
-          n_sample_type <- nrow(plot_data[[1]][[as.numeric(pl_step)]][[measures[1]]])
+          measures <- names(plot_data[[1L]][[1L]])
+          n_sample_type <- nrow(plot_data[[1L]][[as.numeric(pl_step)]][[measures[1L]]])
         }
       } else {
-        n_folds <- 1
-        if (use_pl == FALSE) {
+        n_folds <- 1L
+        if (!use_pl) {
           measures <- names(plot_data[[index_final]])
-          n_sample_type <- nrow(plot_data[[index_final]][[measures[1]]])
+          n_sample_type <- nrow(plot_data[[index_final]][[measures[1L]]])
         } else {
-          measures <- names(plot_data[[index_final]][[1]])
-          n_sample_type <- nrow(plot_data[[index_final]][[as.numeric(pl_step)]][[measures[1]]])
+          measures <- names(plot_data[[index_final]][[1L]])
+          n_sample_type <- nrow(plot_data[[index_final]][[as.numeric(pl_step)]][[measures[1L]]])
         }
       }
 
-      if (n_sample_type == 3) {
+      if (n_sample_type == 3L) {
         sample_type_name <- c("train", "validation", "test")
       } else {
         sample_type_name <- c("train", "validation")
@@ -551,7 +543,7 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
 
       # Create array for saving the data-------------------------------------------
       result_list <- NULL
-      for (j in seq_len(length(measures))) {
+      for (j in seq_along(measures)) {
         measure <- measures[j]
         measure_array <- array(
           dim = c(
@@ -565,7 +557,7 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
         final_data_measure <- matrix(
           data = NA,
           nrow = n_epochs,
-          ncol = 3 * n_sample_type + 1
+          ncol = 3L * n_sample_type + 1L
         )
         colnames(final_data_measure) <- c(
           "epoch",
@@ -578,11 +570,11 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
             )
           )
         )
-        final_data_measure[, "epoch"] <- seq.int(from = 1, to = n_epochs)
+        final_data_measure[, "epoch"] <- seq.int(from = 1L, to = n_epochs)
 
-        if (final == FALSE) {
-          for (i in 1:n_folds) {
-            if (use_pl == FALSE) {
+        if (!final) {
+          for (i in 1L:n_folds) {
+            if (!use_pl) {
               measure_array[i, , ] <- plot_data[[i]][[measure]]
             } else {
               measure_array[i, , ] <- plot_data[[i]][[as.numeric(pl_step)]][[measure]]
@@ -590,13 +582,13 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
           }
         } else {
           if (!use_pl) {
-            measure_array[1, , ] <- plot_data[[index_final]][[measure]]
+            measure_array[1L, , ] <- plot_data[[index_final]][[measure]]
           } else {
-            measure_array[1, , ] <- plot_data[[index_final]][[as.numeric(pl_step)]][[measure]]
+            measure_array[1L, , ] <- plot_data[[index_final]][[as.numeric(pl_step)]][[measure]]
           }
         }
 
-        for (i in 1:n_epochs) {
+        for (i in 1L:n_epochs) {
           final_data_measure[i, "train_min"] <- min(measure_array[, "train", i])
           final_data_measure[i, "train_mean"] <- mean(measure_array[, "train", i])
           final_data_measure[i, "train_max"] <- max(measure_array[, "train", i])
@@ -605,7 +597,7 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
           final_data_measure[i, "validation_mean"] <- mean(measure_array[, "validation", i])
           final_data_measure[i, "validation_max"] <- max(measure_array[, "validation", i])
 
-          if (n_sample_type == 3) {
+          if (n_sample_type == 3L) {
             final_data_measure[i, "test_min"] <- min(measure_array[, "test", i])
             final_data_measure[i, "test_mean"] <- mean(measure_array[, "test", i])
             final_data_measure[i, "test_max"] <- max(measure_array[, "test", i])
@@ -617,6 +609,55 @@ ModelsBasedOnTextEmbeddings <- R6::R6Class(
       # Finalize data---------------------------------------------------------------
       names(result_list) <- measures
       return(result_list)
+    },
+    #---------------------------------------------------------------------------
+    save_pytorch_model = function(dir_path, folder_name) {
+      save_location <- file.path(dir_path, folder_name)
+
+      save_format <- "safetensors"
+
+      if (save_format == "safetensors" & !reticulate::py_module_available("safetensors")) {
+        warning("Python library 'safetensors' is not available. Using
+                 standard save format for pytorch.")
+        save_format <- "pt"
+      }
+
+      create_dir(save_location, FALSE)
+      private$model$to("cpu", dtype = torch$float32)
+      if (save_format == "safetensors") {
+        file_path <- paste0(save_location, "/", "model_data", ".safetensors")
+        safetensors$torch$save_model(model = private$model, filename = file_path)
+      } else if (save_format == "pt") {
+        file_path <- paste0(save_location, "/", "model_data", ".pt")
+        torch$save(private$model$state_dict(), file_path)
+      }
+    },
+    #---------------------------------------------------------------------------
+    load_pytorch_model = function(dir_path) {
+      # Load python scripts
+      private$load_reload_python_scripts()
+
+      # Load the model---------------------------------------------------------
+      path_pt <- paste0(dir_path, "/", "model_data", ".pt")
+      path_safe_tensors <- paste0(dir_path, "/", "model_data", ".safetensors")
+      private$create_reset_model()
+      private$model$to("cpu", dtype = torch$float32)
+
+      if (file.exists(path_safe_tensors)) {
+        safetensors$torch$load_model(
+          model = private$model,
+          filename = path_safe_tensors,
+          device = "cpu"
+        )
+      } else {
+        if (file.exists(paths = path_pt)) {
+          private$model$load_state_dict(torch$load(path_pt))
+        } else {
+          stop("There is no compatible model file in the choosen directory.
+                     Please check path. Please note that classifiers have to be loaded with
+                     the same framework as during creation.")
+        }
+      }
     }
   )
 )
