@@ -17,9 +17,9 @@
 #' @description Base class for classifiers relying on [EmbeddedText] or [LargeDataSetForTextEmbeddings] as input
 #' which use the architecture of Protonets and its corresponding training techniques.
 #'
-#'Objects of this class containing fields and methods used in several other classes in 'AI for Education'.
+#' Objects of this class containing fields and methods used in several other classes in 'AI for Education'.
 #'
-#'This class is **not** designed for a direct application and should only be used by developers.
+#' This class is **not** designed for a direct application and should only be used by developers.
 #'
 #' @return A new object of this class.
 #' @family R6 Classes for Developers
@@ -57,6 +57,7 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
     #' @param sustain_iso_code `r get_param_doc_desc("sustain_iso_code")`
     #' @param sustain_region `r get_param_doc_desc("sustain_region")`
     #' @param sustain_interval `r get_param_doc_desc("sustain_interval")`
+    #' @param sustain_log_level `r get_description("sustain_log_level")`
     #' @param epochs `r get_param_doc_desc("epochs")`
     #' @param batch_size `r get_param_doc_desc("batch_size")`
     #' @param log_dir `r get_param_doc_desc("log_dir")`
@@ -84,39 +85,40 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
     #'
     train = function(data_embeddings = NULL,
                      data_targets = NULL,
-                     data_folds = 5,
+                     data_folds = 5L,
                      data_val_size = 0.25,
                      loss_pt_fct_name = "MultiWayContrastiveLoss",
                      use_sc = FALSE,
                      sc_method = "knnor",
-                     sc_min_k = 1,
-                     sc_max_k = 10,
+                     sc_min_k = 1L,
+                     sc_max_k = 10L,
                      use_pl = FALSE,
-                     pl_max_steps = 3,
+                     pl_max_steps = 3L,
                      pl_max = 1.00,
                      pl_anchor = 1.00,
                      pl_min = 0.00,
                      sustain_track = TRUE,
                      sustain_iso_code = NULL,
                      sustain_region = NULL,
-                     sustain_interval = 15,
-                     epochs = 40,
-                     batch_size = 35,
-                     Ns = 5,
-                     Nq = 3,
+                     sustain_interval = 15L,
+                     sustain_log_level = "warning",
+                     epochs = 40L,
+                     batch_size = 35L,
+                     Ns = 5L,
+                     Nq = 3L,
                      loss_alpha = 0.5,
                      loss_margin = 0.05,
                      sampling_separate = FALSE,
                      sampling_shuffle = TRUE,
                      trace = TRUE,
-                     ml_trace = 1,
+                     ml_trace = 1L,
                      log_dir = NULL,
-                     log_write_interval = 10,
+                     log_write_interval = 10L,
                      n_cores = auto_n_cores(),
                      lr_rate = 1e-3,
                      lr_warm_up_ratio = 0.02,
-                     optimizer="AdamW") {
-      private$do_training(args = get_called_args(n = 1))
+                     optimizer = "AdamW") {
+      private$do_training(args = get_called_args(n = 1L))
     },
     #---------------------------------------------------------------------------
     #' @description Method for predicting the class of given data (query) based on provided examples (sample).
@@ -130,8 +132,8 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
     #' @return Returns a `data.frame` containing the predictions and the probabilities of the different labels for each
     #'   case.
     predict_with_samples = function(newdata,
-                                    batch_size = 32,
-                                    ml_trace = 1,
+                                    batch_size = 32L,
+                                    ml_trace = 1L,
                                     embeddings_s = NULL,
                                     classes_s = NULL) {
       forward_results <- private$forward(
@@ -145,7 +147,7 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       )
 
       # Ids of the rows of newdata
-      #current_row_names <- forward_results$rownames_q
+      # current_row_names <- forward_results$rownames_q
 
       # Possible classes
       class_labels <- forward_results$class_labels
@@ -154,25 +156,25 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       predictions_prob <- forward_results$results
 
       # Index with highest probability
-      predictions <- max.col(predictions_prob) - 1
+      predictions <- max.col(predictions_prob) - 1L
 
       # Transforming predictions to target levels------------------------------
       predictions <- as.character(as.vector(predictions))
-      for (i in 0:(length(class_labels) - 1)) {
+      for (i in 0L:(length(class_labels) - 1L)) {
         predictions <- replace(
           x = predictions,
           predictions == as.character(i),
-          values = class_labels[i + 1]
+          values = class_labels[i + 1L]
         )
       }
 
       # Transforming to a factor
       predictions <- factor(predictions, levels = class_labels)
 
-      #colnames(predictions_prob) <- class_labels
+      # colnames(predictions_prob) <- class_labels
       predictions_prob <- as.data.frame(predictions_prob)
       predictions_prob$expected_category <- predictions
-      #rownames(predictions_prob) <- current_row_names
+      # rownames(predictions_prob) <- current_row_names
       return(predictions_prob)
     },
     #---------------------------------------------------------------------------
@@ -194,11 +196,11 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
     #' * `embeddings_prototypes`: embeddings of the prototypes which were learned during training. They represents the
     #'    center for the different classes.
     #'
-    embed = function(embeddings_q = NULL, embeddings_s = NULL, classes_s = NULL, batch_size = 32,ml_trace = 1) {
+    embed = function(embeddings_q = NULL, embeddings_s = NULL, classes_s = NULL, batch_size = 32L, ml_trace = 1L) {
       # Load Custom Model Scripts
       private$load_reload_python_scripts()
 
-      #Check arguments and forward
+      # Check arguments and forward
       forward_results <- private$forward(
         embeddings_q = embeddings_q,
         classes_q = NULL,
@@ -211,17 +213,17 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
 
       return(
         list(
-        embeddings_q = forward_results$results$embeddings_query,
-        distances_q = forward_results$results$embeddings_query,
-        embeddings_prototypes = forward_results$results$prototype_embeddings
-      )
+          embeddings_q = forward_results$results$embeddings_query,
+          distances_q = forward_results$results$embeddings_query,
+          embeddings_prototypes = forward_results$results$prototype_embeddings
+        )
       )
     },
     #---------------------------------------------------------------------------
     #' @description Method returns the scaling factor of the metric.
     #' @return Returns the scaling factor of the metric as `float`.
-    get_metric_scale_factor=function(){
-      return(tensor_to_numpy(self$model$get_metric_scale_factor()))
+    get_metric_scale_factor = function() {
+      return(tensor_to_numpy(private$model$get_metric_scale_factor()))
     },
     #---------------------------------------------------------------------------
     #' @description Method for creating a plot to visualize embeddings and their corresponding centers (prototypes).
@@ -246,23 +248,23 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
                                classes_q = NULL,
                                embeddings_s = NULL,
                                classes_s = NULL,
-                               batch_size = 12,
+                               batch_size = 12L,
                                alpha = 0.5,
-                               size_points = 3,
-                               size_points_prototypes = 8,
+                               size_points = 3L,
+                               size_points_prototypes = 8L,
                                inc_unlabeled = TRUE,
-                               inc_margin=TRUE) {
+                               inc_margin = TRUE) {
       # Argument checking-------------------------------------------------------
-      #Do forward
-        forward_results <- private$forward(
-          embeddings_q = embeddings_q,
-          classes_q = NULL,
-          batch_size = batch_size,
-          ml_trace = 0,
-          embeddings_s = embeddings_s,
-          classes_s = classes_s,
-          prediction_mode = FALSE
-        )
+      # Do forward
+      forward_results <- private$forward(
+        embeddings_q = embeddings_q,
+        classes_q = NULL,
+        batch_size = batch_size,
+        ml_trace = 0L,
+        embeddings_s = embeddings_s,
+        classes_s = classes_s,
+        prediction_mode = FALSE
+      )
 
       prototypes <- as.data.frame(forward_results$results$prototype_embeddings)
       prototypes$class <- rownames(forward_results$results$prototype_embeddings)
@@ -270,9 +272,9 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       colnames(prototypes) <- c("x", "y", "class", "type")
 
       if (!is.null(classes_q)) {
-        #Check classes of q and sample
-        labels_sample_and_query=intersect(x=rownames(forward_results$results$prototype_embeddings),levels(classes_q))
-        classes_q[!(classes_q%in%labels_sample_and_query)]=NA
+        # Check classes of q and sample
+        labels_sample_and_query <- intersect(x = rownames(forward_results$results$prototype_embeddings), levels(classes_q))
+        classes_q[!(classes_q %in% labels_sample_and_query)] <- NA
 
         true_values_names <- intersect(
           x = names(na.omit(classes_q)),
@@ -288,25 +290,25 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       }
 
 
-      if (inc_unlabeled == TRUE) {
+      if (inc_unlabeled) {
         estimated_values_names <- setdiff(
           x = private$get_rownames_from_embeddings(embeddings_q),
           y = true_values_names
         )
 
-        if (length(estimated_values_names) > 0) {
+        if (length(estimated_values_names) > 0L) {
           estimated_values <- as.data.frame(forward_results$results$embeddings_query[estimated_values_names, , drop = FALSE])
-          #Get Classes
+          # Get Classes
           class_labels <- forward_results$class_labels
-          predictions_prob=forward_results$results$predictions_prob[estimated_values_names, , drop = FALSE]
-          predictions <- max.col(predictions_prob) - 1
+          predictions_prob <- forward_results$results$predictions_prob[estimated_values_names, , drop = FALSE]
+          predictions <- max.col(predictions_prob) - 1L
           # Transforming predictions to target levels------------------------------
           predictions <- as.character(as.vector(predictions))
-          for (i in 0:(length(class_labels) - 1)) {
+          for (i in 0L:(length(class_labels) - 1L)) {
             predictions <- replace(
               x = predictions,
               predictions == as.character(i),
-              values = class_labels[i + 1]
+              values = class_labels[i + 1L]
             )
           }
 
@@ -320,14 +322,14 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
 
 
       plot_data <- prototypes
-      if (length(true_values) > 0) {
+      if (length(true_values) > 0L) {
         plot_data <- rbind(plot_data, true_values)
       }
-      if (length(estimated_values_names) > 0) {
+      if (length(estimated_values_names) > 0L) {
         plot_data <- rbind(plot_data, estimated_values)
       }
 
-      plot <- ggplot2::ggplot(data = plot_data) +
+      tmp_plot <- ggplot2::ggplot(data = plot_data) +
         ggplot2::geom_point(
           mapping = ggplot2::aes(
             x = x,
@@ -340,43 +342,43 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
           # position = ggplot2::position_jitter(h = 0.1, w = 0.1)
         ) +
         ggplot2::scale_size_manual(values = c(
-          "prototype" = size_points_prototypes,
-          "labeled" = size_points,
-          "unlabeled" = size_points
+          prototype = size_points_prototypes,
+          labeled = size_points,
+          unlabeled = size_points
         )) +
         ggplot2::scale_alpha_manual(
           values = c(
-            "prototype" = 1,
-            "labeled" = alpha,
-            "unlabeled" = alpha
+            prototype = 1L,
+            labeled = alpha,
+            unlabeled = alpha
           )
         ) +
         ggplot2::scale_shape_manual(
           values = c(
-            "prototype" = 17,
-            "labeled" = 16,
-            "unlabeled" = 15
+            prototype = 17L,
+            labeled = 16L,
+            unlabeled = 15L
           )
-        )+
+        ) +
         ggplot2::theme_classic()
 
-      if(inc_margin==TRUE){
-        margin=self$last_training$config$loss_margin
-        #scaled_margin=margin*self$get_metric_scale_factor()
-        if(!is.null(margin)){
-          for(i in 1:nrow(prototypes)){
-            current_proto=prototypes[i,]
-            plot=plot+ggplot2::annotate(
-              geom="point",
-              x=current_proto$x+margin*cos(seq(from=0,to=2*base::pi,length.out=1000)),
-              y=current_proto$y+margin*sin(seq(from=0,to=2*base::pi,length.out=1000)),
+      if (inc_margin) {
+        margin <- self$last_training$config$loss_margin
+        # scaled_margin=margin*self$get_metric_scale_factor()
+        if (!is.null(margin)) {
+          for (i in seq_len(nrow(prototypes))) {
+            current_proto <- prototypes[i, ]
+            tmp_plot <- tmp_plot + ggplot2::annotate(
+              geom = "point",
+              x = current_proto$x + margin * cos(seq(from = 0L, to = 2L * base::pi, length.out = 1000L)),
+              y = current_proto$y + margin * sin(seq(from = 0L, to = 2L * base::pi, length.out = 1000L))
             )
           }
         } else {
           warning("Last training has not provided a valid margin. Creating plot without margin.")
         }
       }
-      return(plot)
+      return(tmp_plot)
     }
   ),
   private = list(
@@ -385,34 +387,34 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
                        classes_q = NULL,
                        embeddings_s = NULL,
                        classes_s = NULL,
-                       batch_size = 32,
-                       ml_trace = 1,
+                       batch_size = 32L,
+                       ml_trace = 1L,
                        prediction_mode = TRUE) {
       # Check arguments
       check_class(object = embeddings_q, classes = c("EmbeddedText", "LargeDataSetForTextEmbeddings"), allow_NULL = FALSE)
-      check_class(object = classes_q, classes = c("factor"), allow_NULL = TRUE)
+      check_class(object = classes_q, classes = "factor", allow_NULL = TRUE)
       check_class(object = embeddings_s, classes = c("EmbeddedText", "LargeDataSetForTextEmbeddings"), allow_NULL = TRUE)
-      check_class(object = classes_s, classes = c("factor"), allow_NULL = TRUE)
+      check_class(object = classes_s, classes = "factor", allow_NULL = TRUE)
       check_type(object = batch_size, object_name = "batch_size", type = "int", FALSE)
       check_type(object = ml_trace, object_name = "ml_trace", type = "int", FALSE)
       check_type(object = prediction_mode, object_name = "prediction_mode", type = "bool")
 
-      if((is.null(embeddings_s)& !is.null(classes_s))){
+      if ((is.null(embeddings_s) & !is.null(classes_s))) {
         warning("embeddings_s is not set but classes_s is set. Conitnue with setting both to NULL")
-        classes_s=NULL
+        classes_s <- NULL
       }
-      if((!is.null(embeddings_s)& is.null(classes_s))){
+      if ((!is.null(embeddings_s) & is.null(classes_s))) {
         warning("embeddings_s is set but classes_s is not set. Conitnue with setting both to NULL")
-        embeddings_s=NULL
+        embeddings_s <- NULL
       }
 
       # Load Custom Model Scripts
       private$load_reload_python_scripts()
 
       # prepare embeddings
-      embeddings_q <- private$prepare_embeddings_for_forward(embeddings_q,batch_size = batch_size)
+      embeddings_q <- private$prepare_embeddings_for_forward(embeddings_q, batch_size = batch_size)
       if (!is.null(embeddings_s)) {
-        embeddings_s <- private$prepare_embeddings_for_forward(embeddings_s,batch_size = batch_size)
+        embeddings_s <- private$prepare_embeddings_for_forward(embeddings_s, batch_size = batch_size)
       }
 
       # Check number of cases in the data
@@ -423,17 +425,17 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
 
       # Prepare classes for sample
       if (!is.null(classes_s)) {
-        class_freq_table=table(na.omit(classes_s))
-        class_freq_table=subset(class_freq_table,class_freq_table>0)
+        class_freq_table <- table(na.omit(classes_s))
+        class_freq_table <- subset(class_freq_table, class_freq_table > 0L)
         class_labels <- names(class_freq_table)
 
         classes_s <- as.character(classes_s)
-        for(i in seq_along(class_labels)){
-          classes_s[classes_s==class_labels[i]]=i
+        for (i in seq_along(class_labels)) {
+          classes_s[classes_s == class_labels[i]] <- i
         }
-        classes_s=as.numeric(classes_s)-1
+        classes_s <- as.numeric(classes_s) - 1L
       } else {
-        class_labels <- self$model_config$target_levels
+        class_labels <- private$model_config$target_levels
         classes_s <- NULL
       }
 
@@ -441,13 +443,13 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       if (!is.null(classes_q)) {
         classes_q <- as.character(classes_q)
         classes_q <- factor(x = classes_q, levels = class_labels)
-        classes_q <- as.numeric(classes_q) - 1
+        classes_q <- as.numeric(classes_q) - 1L
       } else {
         classes_q <- NULL
       }
 
       # Prepare data for pytorch
-      if(!is.null(embeddings_s)){
+      if (!is.null(embeddings_s)) {
         embeddings_s <- embeddings_s$get_dataset()
         embeddings_s$set_format("torch")
         embeddings_s <- embeddings_s[["input"]]
@@ -461,12 +463,12 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       }
 
       # If at least two cases are part of the data set---------------------------
-      if (single_prediction == FALSE) {
+      if (!single_prediction) {
         prediction_data <- private$prepare_embeddings_as_dataset(embeddings_q)
         prediction_data$set_format("torch")
 
         results <- py$TeProtoNetClassifierBatchPredict(
-          model = self$model,
+          model = private$model,
           dataset = prediction_data,
           batch_size = as.integer(batch_size),
           embeddings_s = embeddings_s,
@@ -496,9 +498,9 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
         if (!is.null(embeddings_s)) {
           embeddings_s <- embeddings_s$to(device, dtype = dtype)
         }
-        self$model$to(device, dtype = dtype)
-        self$model$eval()
-        results <- self$model(
+        private$model$to(device, dtype = dtype)
+        private$model$eval()
+        results <- private$model(
           input_q = prediction_data$to(device, dtype = dtype),
           input_s = embeddings_s$to(device, dtype = dtype),
           classes_s = classes_s$to(device, dtype = dtype),
@@ -506,68 +508,68 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
         )
       }
 
-      if(prediction_mode==TRUE){
-        results<-tensor_to_numpy(results)
-        rownames(results)=current_row_names
-        colnames(results)=as.character(class_labels)
+      if (prediction_mode) {
+        results <- tensor_to_numpy(results)
+        rownames(results) <- current_row_names
+        colnames(results) <- as.character(class_labels)
       } else {
-        results<-tensor_list_to_numpy(results)
+        results <- tensor_list_to_numpy(results)
 
-        predictions=results[[1]]
-        rownames(predictions)=current_row_names
-        colnames(predictions)=as.character(class_labels)
+        predictions <- results[[1L]]
+        rownames(predictions) <- current_row_names
+        colnames(predictions) <- as.character(class_labels)
 
-        distances=results[[2]]
-        rownames(distances)=current_row_names
-        colnames(distances)=as.character(class_labels)
+        distances <- results[[2L]]
+        rownames(distances) <- current_row_names
+        colnames(distances) <- as.character(class_labels)
 
-        embeddings_query=results[[4]]
-        rownames(embeddings_query)=current_row_names
+        embeddings_query <- results[[4L]]
+        rownames(embeddings_query) <- current_row_names
 
-        prototype_embeddings=results[[5]]
-        rownames(prototype_embeddings)=as.character(class_labels)
+        prototype_embeddings <- results[[5L]]
+        rownames(prototype_embeddings) <- as.character(class_labels)
 
-        results=list(
-          predictions_prob=predictions,
-          distances=distances,
-          embeddings_query=embeddings_query,
-          prototype_embeddings=prototype_embeddings
+        results <- list(
+          predictions_prob = predictions,
+          distances = distances,
+          embeddings_query = embeddings_query,
+          prototype_embeddings = prototype_embeddings
         )
       }
 
-      return(list(results = results,
-        class_labels = class_labels#,
-        #rownames_q = current_row_names
-      )
-      )
+      return(list(
+        results = results,
+        class_labels = class_labels # ,
+        # rownames_q = current_row_names
+      ))
     },
     #-------------------------------------------------------------------------
-    prepare_embeddings_for_forward = function(embeddings,batch_size) {
+    prepare_embeddings_for_forward = function(embeddings, batch_size) {
       # Check if the embeddings must be compressed before passing to the model
       requires_compression <- self$requires_compression(embeddings)
 
       # Check input for compatible text embedding models and feature extractors
       if (
-        "EmbeddedText" %in% class(embeddings) |
-          "LargeDataSetForTextEmbeddings" %in% class(embeddings)
+        inherits(embeddings, "EmbeddedText") |
+          inherits(embeddings, "LargeDataSetForTextEmbeddings")
       ) {
         self$check_embedding_model(text_embeddings = embeddings, require_compressed = FALSE)
       } else {
         private$check_embeddings_object_type(embeddings, strict = FALSE)
-        if (requires_compression == TRUE) {
+        if (requires_compression) {
           stop("Objects of class datasets.arrow_dataset.Dataset must be provided in
                compressed form.")
         }
       }
 
       # Convert to a LargeDataSetForTextEmbeddings
-      if ("EmbeddedText" %in% class(embeddings)) {
+      if (inherits(embeddings, "EmbeddedText")) {
         embeddings <- embeddings$convert_to_LargeDataSetForTextEmbeddings()
       } else {
         embeddings <- embeddings
       }
 
-      if (requires_compression == TRUE) {
+      if (requires_compression) {
         # Returns a data set
         embeddings <- self$feature_extractor$extract_features_large(
           data_embeddings = embeddings,
@@ -578,23 +580,23 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       return(embeddings)
     },
     #-------------------------------------------------------------------------
-    set_random_prototypes=function(){
-      n_row <- length(self$model_config$target_levels)
-      n_col <- self$model_config$embedding_dim
-      self$model$set_trained_prototypes(
+    set_random_prototypes = function() {
+      n_row <- length(private$model_config$target_levels)
+      n_col <- private$model_config$embedding_dim
+      private$model$set_trained_prototypes(
         prototypes = torch$from_numpy(
           reticulate::np_array(
             matrix(
               nrow = n_row,
               ncol = n_col,
-              data = rnorm(n = n_col * n_row, mean = 0, sd = 1)
+              data = rnorm(n = n_col * n_row, mean = 0L, sd = 1L)
             )
           )
         ),
         class_lables = reticulate::np_array(
           seq(
-            from = 0,
-            to = (length(self$model_config$target_levels) - 1)
+            from = 0L,
+            to = (length(private$model_config$target_levels) - 1L)
           )
         )
       )
@@ -606,7 +608,7 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
                            reset_model = FALSE,
                            use_callback = TRUE,
                            log_dir = NULL,
-                           log_write_interval = 10,
+                           log_write_interval = 10L,
                            log_top_value = NULL,
                            log_top_total = NULL,
                            log_top_message = NULL) {
@@ -616,7 +618,7 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       }
 
       # Reset model if requested
-      if (reset_model == TRUE) {
+      if (reset_model) {
         private$create_reset_model()
       }
 
@@ -624,28 +626,28 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       loss_cls_fct_name <- "ProtoNetworkMargin"
 
       # Set target column
-      if (self$model_config$require_one_hot == FALSE) {
+      if (!private$model_config$require_one_hot) {
         target_column <- "labels"
       } else {
         target_column <- "one_hot_encoding"
       }
 
       dataset_train <- train_data$select_columns(c("input", target_column))
-      if (self$model_config$require_one_hot == TRUE) {
+      if (private$model_config$require_one_hot) {
         dataset_train <- dataset_train$rename_column(target_column, "labels")
       }
 
       pytorch_train_data <- dataset_train$with_format("torch")
 
       pytorch_val_data <- val_data$select_columns(c("input", target_column))
-      if (self$model_config$require_one_hot == TRUE) {
+      if (private$model_config$require_one_hot) {
         pytorch_val_data <- pytorch_val_data$rename_column(target_column, "labels")
       }
       pytorch_val_data <- pytorch_val_data$with_format("torch")
 
       if (!is.null(test_data)) {
         pytorch_test_data <- test_data$select_columns(c("input", target_column))
-        if (self$model_config$require_one_hot == TRUE) {
+        if (private$model_config$require_one_hot) {
           pytorch_test_data <- pytorch_test_data$rename_column(target_column, "labels")
         }
         pytorch_test_data <- pytorch_test_data$with_format("torch")
@@ -653,8 +655,8 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
         pytorch_test_data <- NULL
       }
 
-      history <- py$TeClassifierTrainPrototype(
-        model = self$model,
+      tmp_history <- py$TeClassifierTrainPrototype(
+        model = private$model,
         loss_pt_fct_name = self$last_training$config$loss_pt_fct_name,
         optimizer_method = self$last_training$config$optimizer,
         lr_rate = self$last_training$config$lr_rate,
@@ -671,8 +673,8 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
         epochs = as.integer(self$last_training$config$epochs),
         sampling_separate = self$last_training$config$sampling_separate,
         sampling_shuffle = self$last_training$config$sampling_shuffle,
-        filepath = paste0(private$dir_checkpoint, "/best_weights.pt"),
-        n_classes = as.integer(length(self$model_config$target_levels)),
+        filepath = file.path(private$dir_checkpoint, "best_weights.pt"),
+        n_classes = as.integer(length(private$model_config$target_levels)),
         log_dir = log_dir,
         log_write_interval = log_write_interval,
         log_top_value = log_top_value,
@@ -681,9 +683,9 @@ TEClassifiersBasedOnProtoNet <- R6::R6Class(
       )
 
       # provide rownames and replace -100
-      history <- private$prepare_history_data(history)
+      tmp_history <- private$prepare_history_data(tmp_history)
 
-      return(history)
+      return(tmp_history)
     }
   )
 )
