@@ -12,35 +12,49 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>
 
-#'Transforming classes to one-hot encoding
+#' Time stamp
 #'
-#'Function transforming a vector of classes (int) into
-#'a binary class matrix.
+#' Function returns the time on the machine at the moment of calling.
 #'
-#'@param class_vector `vector` containing integers for every class. The
-#'integers must range from 0 to n_classes-1.
-#'@param n_classes `int` Total number of classes.
-#'@return Returns a `matrix` containing the binary representation for
-#'every class.
+#' @return Returns a `string` with date and time in format "%y-%m-%d %H:%M:%S".
 #'
-#'@family Utils Developers
-#'@export
-to_categorical_c=function(class_vector,n_classes){
+#' @family Utils Developers
+#' @export
+get_time_stamp <- function() {
+  return(
+    as.character(format(Sys.time()), "%y-%m-%d %H:%M:%S")
+  )
+}
 
-   binary_class_rep=matrix(
-     data=0,
-     nrow=length(class_vector),
-     ncol=n_classes)
+#' Transforming classes to one-hot encoding
+#'
+#' Function transforming a vector of classes (int) into
+#' a binary class matrix.
+#'
+#' @param class_vector `vector` containing integers for every class. The
+#' integers must range from 0 to n_classes-1.
+#' @param n_classes `int` Total number of classes.
+#' @return Returns a `matrix` containing the binary representation for
+#' every class.
+#'
+#' @family Utils Developers
+#' @export
+to_categorical_c <- function(class_vector, n_classes) {
+  binary_class_rep <- matrix(
+    data = 0L,
+    nrow = length(class_vector),
+    ncol = n_classes
+  )
 
-   for(i in seq_along(class_vector)){
-     binary_class_rep[i,class_vector[i]+1]=1
-     }
+  for (i in seq_along(class_vector)) {
+    binary_class_rep[i, class_vector[i] + 1L] <- 1L
+  }
 
-   return (binary_class_rep)
- }
+  return(binary_class_rep)
+}
 
 #' @title Check if NULL or NA
-#' @description Function for checking if an object is `NULL` or .
+#' @description Function for checking if an object is `NULL` or `NA`.
 #'
 #' @param object An object to test.
 #' @return Returns `FALSE` if the object is not `NULL` and not `NA`. Returns `TRUE` in all other cases.
@@ -78,42 +92,42 @@ array_form_bind <- function(...) {
   for (object in objects) {
     if (is.list(object)) {
       for (j in seq_len(length(object))) {
-        arrays[length(arrays) + 1] <- list(object[[j]])
+        arrays[length(arrays) + 1L] <- list(object[[j]])
       }
     } else {
-      arrays[length(arrays) + 1] <- list(object)
+      arrays[length(arrays) + 1L] <- list(object)
     }
   }
 
   # arrays <- list(...)
-  if (length(arrays) > 1) {
-    total_rows <- 0
+  if (length(arrays) > 1L) {
+    total_rows <- 0L
 
-    dimension <- dim(arrays[[1]])
+    dimension <- dim(arrays[[1L]])
 
     for (i in seq_len(length(arrays))) {
-      total_rows <- total_rows + dim(arrays[[i]])[1]
+      total_rows <- total_rows + dim(arrays[[i]])[1L]
 
       # Check number of dimensions
-      if (sum(dim(arrays[[i]])[-1] != dimension[-1])) {
+      if (sum(dim(arrays[[i]])[-1L] != dimension[-1L])) {
         stop("The dimensions of the array differ.")
       }
     }
 
     combined_array <- array(
       data = NA,
-      dim = c(total_rows, dimension[2], dimension[3])
+      dim = c(total_rows, dimension[2L], dimension[3L])
     )
 
-    intercept <- 0
+    intercept <- 0L
     row_names <- NULL
 
 
     for (i in seq_len(length(arrays))) {
       index <- seq.int(
-        from = 1,
+        from = 1L,
         to = nrow(arrays[[i]]),
-        by = 1
+        by = 1L
       ) + intercept
 
       combined_array[index, , ] <- arrays[[i]]
@@ -126,7 +140,7 @@ array_form_bind <- function(...) {
     rownames(combined_array) <- row_names
     return(combined_array)
   } else {
-    return(arrays[[1]])
+    return(arrays[[1L]])
   }
 }
 
@@ -140,7 +154,7 @@ array_form_bind <- function(...) {
 #' @return Returns a `string` of the requested length.
 #' @family Utils Developers
 #' @export
-generate_id <- function(length = 16) {
+generate_id <- function(length = 16L) {
   id_suffix <- NULL
   sample_values <- c(
     "a", "A",
@@ -169,7 +183,7 @@ generate_id <- function(length = 16) {
     "x", "X",
     "y", "Y",
     "z", "Z",
-    seq(from = 0, to = 9, by = 1)
+    seq(from = 0L, to = 9L, by = 1L)
   )
 
 
@@ -200,49 +214,11 @@ auto_n_cores <- function() {
       Sys.getenv("NOT_CRAN") == "true" ||
       Sys.getenv("_R_CHECK_LIMIT_CORES_") == "true"
   ) {
-    n_cores <- min(2, parallel::detectCores())
-
+    n_cores <- min(2L, parallel::detectCores())
   } else {
     n_cores <- floor(parallel::detectCores() * 0.75)
   }
-  return(n_cores = max(1, n_cores))
-}
-
-#' @title Create object
-#'
-#' @description  Support function for creating objects.
-#' @param class `string` Name of the class to be created.#'
-#' @return Returns an object of the requested class.#'
-#' @family Utils Developers
-#' @export
-create_object=function(class){
-  if(class=="TEClassifierRegular"){
-    return(suppressMessages(TEClassifierRegular$new()))
-  } else if(class=="TEClassifierProtoNet"){
-    return(suppressMessages(TEClassifierProtoNet$new()))
-  } else if(class=="TEClassifierSequential"){
-    return(TEClassifierSequential$new())
-  }else if(class=="TEClassifierSequentialPrototype"){
-    return(TEClassifierSequentialPrototype$new())
-  }else if(class=="TEClassifierParallel"){
-    return(TEClassifierParallel$new())
-  }else if(class=="TEClassifierParallelPrototype"){
-    return(TEClassifierParallelPrototype$new())
-  }else if(class=="TEFeatureExtractor"){
-    return(TEFeatureExtractor$new())
-  }  else if (class == "TextEmbeddingModel") {
-    return(TextEmbeddingModel$new())
-  } else if (class == "LargeDataSetForTextEmbeddings") {
-   return(LargeDataSetForTextEmbeddings$new())
-  } else if (class == "LargeDataSetForText") {
-    return(LargeDataSetForText$new())
-  } else if (class == "EmbeddedText") {
-    return(EmbeddedText$new())
-  } else if(class%in%unlist(AIFETrType)){
-    return(aife_transformer.make(type=class,init_trace = FALSE))
-  } else {
-    stop("Object is not implemented in this function.")
-  }
+  return(n_cores = max(1L, n_cores))
 }
 
 #' @title Detect base model's architecture
@@ -255,28 +231,28 @@ create_object=function(class){
 #' @family Utils Developers
 #' @keywords internal
 #' @noRd
-detect_base_model_type=function(model){
-  if(("transformers.configuration_utils.PretrainedConfig")%in%class(model)){
-    type_string=model$architectures
+detect_base_model_type <- function(model) {
+  if (inherits(model, "transformers.configuration_utils.PretrainedConfig")) {
+    type_string <- model$architectures
   } else {
-    type_string=model$config
+    type_string <- model$config
   }
 
-  if(stringi::stri_detect(str=tolower(type_string),regex = "^funnel([:alnum:]*)")){
+  if (stringi::stri_detect(str = tolower(type_string), regex = "^funnel([:alnum:]*)")) {
     return("funnel")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^bert([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^bert([:alnum:]*)")) {
     return("bert")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^debertav2([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^debertav2([:alnum:]*)")) {
     return("deberta_v2")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^mpnet([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^mpnet([:alnum:]*)")) {
     return("mpnet")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^longformer([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^longformer([:alnum:]*)")) {
     return("longformer")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^roberta([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^roberta([:alnum:]*)")) {
     return("roberta")
-  } else if(stringi::stri_detect(str=tolower(type_string),regex = "^modernbert([:alnum:]*)")){
+  } else if (stringi::stri_detect(str = tolower(type_string), regex = "^modernbert([:alnum:]*)")) {
     return("modernbert")
   } else {
-    stop("Architectue for the model could not be detected.")
+    stop("Architecture for the model could not be detected.")
   }
 }
